@@ -96,7 +96,7 @@ impl Display for ParamDef {
         write!(
           f,
           "{{{}}}{}",
-          SliceDisplayer::new(&props, ", ", false),
+          SliceDisplayer::new(props, ", ", false),
           display_optional(*optional)
         )?;
         if let Some(ts_type) = ts_type {
@@ -248,7 +248,7 @@ pub fn pat_to_param_def(
   source_map: Option<&SourceMap>,
 ) -> ParamDef {
   match pat {
-    Pat::Ident(ident) => ident_to_param_def(&ident, source_map),
+    Pat::Ident(ident) => ident_to_param_def(ident, source_map),
     Pat::Array(array_pat) => array_pat_to_param_def(array_pat, source_map),
     Pat::Rest(rest_pat) => rest_pat_to_param_def(rest_pat, source_map),
     Pat::Object(object_pat) => object_pat_to_param_def(object_pat, source_map),
@@ -262,7 +262,7 @@ pub fn ts_fn_param_to_param_def(
   source_map: Option<&SourceMap>,
 ) -> ParamDef {
   match ts_fn_param {
-    TsFnParam::Ident(ident) => ident_to_param_def(&ident, source_map),
+    TsFnParam::Ident(ident) => ident_to_param_def(ident, source_map),
     TsFnParam::Array(array_pat) => {
       array_pat_to_param_def(array_pat, source_map)
     }
